{ lib, pkgs, ... }:

{
  imports = [
    # Import hardware configuration
    ./hardware-configuration.nix

    # Import modules
    ../../modules/system
  ];

  settings = {
    hostname = "ti-clt-tbl01";
    display-manager = "gdm";
    desktop-environments = {
      cosmic.enable = false;
      hyprland.enable = false;
      gnome.enable = true;
    };
    applications = {
      common.enable = true;
      steam.enable = false;
      thunar.enable = false;
    };
    services = {
      docker.enable = false;
      quickemu.enable = false;
      sunshine.enable = false;
      garbage-collection.enable = true;
    };
    hardware = {
      fprint.enable = false;
      printing.enable = false;
      bluetooth.enable = true;
      firewall.enable = true;
      locale.enable = true;
      nvidia.enable = false;
    };
  };

  # Users
  users.users.xeovalyte = {
    isNormalUser = true;
    description = "Timo Boomers";
    extraGroups = [ "networkmanager" "wheel" "dialout" ];
  };

  # Bootloader.
  boot.loader.efi.canTouchEfiVariables = true;
  boot.loader.grub = {
    enable = true;
    efiSupport = true;
    device = "nodev";
    configurationLimit = 32;
  };
  boot.kernelPackages = lib.mkForce pkgs.linuxPackages_latest;

  system.stateVersion = "24.11";

}
